================================
ATLAS Rucio Integration Test-bed
================================

**Authentication**

DNS: `http://atlas-rucio-auth.cern.ch/ <http://atlas-rucio-auth.cern.ch/ping>`_

* `voatlas298 <http://lemonweb.cern.ch/lemon-status/info.php?entity=voatlas298>`_, `AWStats <http://voatlas298.cern.ch/awstats/awstats.pl?output=main&config=voatlas298.cern.ch&framename=index>`_
* `voatlas299 <http://lemonweb.cern.ch/lemon-status/info.php?entity=voatlas299>`_, `AWStats <http://voatlas299.cern.ch/awstats/awstats.pl?output=main&config=voatlas299.cern.ch&framename=index>`_

**Load Balancer/Proxy/Cache**

DNS: `http://atlas-rucio.cern.ch/ <http://atlas-rucio.cern.ch/ping>`_

* `voatlas304 <http://lemonweb.cern.ch/lemon-status/info.php?entity=voatlas304>`_, `Munin monitoring <http://voatlas304.cern.ch:1080/munin/cern.ch/voatlas304/index.html#varnish>`_
* `voatlas305 <http://lemonweb.cern.ch/lemon-status/info.php?entity=voatlas305>`_, `Munin monitoring <http://voatlas305.cern.ch:1080/munin/cern.ch/voatlas305/index.html#varnish>`_

**Reader Backend**

* `voatlas300 <http://lemonweb.cern.ch/lemon-status/info.php?entity=voatlas300>`_, `AWStats <http://voatlas300.cern.ch/awstats/awstats.pl?output=main&config=voatlas300.cern.ch&framename=index>`_
* `voatlas301 <http://lemonweb.cern.ch/lemon-status/info.php?entity=voatlas301>`_, `AWStats <http://voatlas301.cern.ch/awstats/awstats.pl?output=main&config=voatlas301.cern.ch&framename=index>`_

**Writer Backend**

* `voatlas302 <http://lemonweb.cern.ch/lemon-status/info.php?entity=voatlas302>`_, `AWStats <http://voatlas302.cern.ch/awstats/awstats.pl?output=main&config=voatlas302.cern.ch&framename=index>`_
* `voatlas303 <http://lemonweb.cern.ch/lemon-status/info.php?entity=voatlas303>`_, `AWStats <http://voatlas303.cern.ch/awstats/awstats.pl?output=main&config=voatlas303.cern.ch&framename=index>`_


**Daemons**

* `voatlas63 <http://lemonweb.cern.ch/lemon-status/info.php?entity=voatlas63>`_

**Graphite**

* `voatlas70 <http://lemonweb.cern.ch/lemon-status/info.php?entity=voatlas70>`_, `Monitoring <http://voatlas70.cern.ch>`_


**Nagios**

* `voatlas143 <http://lemonweb.cern.ch/lemon-status/info.php?entity=voatlas143>`_, `Nagios monitoring <http://voatlas143.cern.ch/nagios/>`_



